@@ -27,8 +27,8 @@ if (
         )
     except Exception as e:
         print("Error code: ")
-else:
-    print("M3 Config exits from: 11/07/2020")
+#else:
+    #print("M3 Config exits from: 11/07/2020")
 
 
 class bcolors:
